@@ -1,12 +1,12 @@
-from marshmallow import Schema, fields, post_load
+from marshmallow import fields
 
 from flag_engine.environments.integrations.models import IntegrationModel
+from flag_engine.utils.marshmallow.schemas import LoadToModelSchema
 
 
-class IntegrationSchema(Schema):
+class IntegrationSchema(LoadToModelSchema):
     api_key = fields.Str(required=False, allow_none=True)
     base_url = fields.Str(required=False, allow_none=True)
 
-    @post_load()
-    def make_integration_model(self, data, **kwargs):
-        return IntegrationModel(**data)
+    class Meta:
+        model_class = IntegrationModel
