@@ -1,6 +1,6 @@
 import uuid
 
-from marshmallow import EXCLUDE, Schema, fields, post_load, validate
+from marshmallow import EXCLUDE, Schema, fields, post_dump, post_load, validate
 
 from flag_engine.features.models import (
     FeatureModel,
@@ -8,6 +8,7 @@ from flag_engine.features.models import (
     MultivariateFeatureOptionModel,
     MultivariateFeatureStateValueModel,
 )
+from flag_engine.utils.exceptions import InvalidPercentageAllocation
 from flag_engine.utils.marshmallow.schemas import LoadToModelSchema
 
 
@@ -21,6 +22,7 @@ class FeatureSchema(LoadToModelSchema):
 
 
 class MultivariateFeatureOptionSchema(LoadToModelSchema):
+    id = fields.Int(allow_none=True)
     value = fields.Field(allow_none=True)
 
     class Meta:
@@ -28,7 +30,8 @@ class MultivariateFeatureOptionSchema(LoadToModelSchema):
 
 
 class MultivariateFeatureStateValueSchema(LoadToModelSchema):
-    id = fields.Int()
+    id = fields.Int(allow_none=True)
+    mv_fs_value_uuid = fields.Str(dump_default=uuid.uuid4)
     multivariate_feature_option = fields.Nested(MultivariateFeatureOptionSchema)
     percentage_allocation = fields.Decimal(validate=[validate.Range(0, 100)])
 
@@ -50,6 +53,7 @@ class FeatureStateSchema(BaseFeatureStateSchema):
     multivariate_feature_state_values = fields.List(
         fields.Nested(MultivariateFeatureStateValueSchema)
     )
+    django_id = fields.Int(allow_none=True)
 
     class Meta:
         unknown = EXCLUDE
@@ -60,3 +64,18 @@ class FeatureStateSchema(BaseFeatureStateSchema):
         feature_state = FeatureStateModel(**data)
         feature_state.set_value(value)
         return feature_state
+
+    @post_dump()
+    def validate_percentage_allocations(self, data, **kwargs):
+        """Since we do support modifying percentage allocation on a per identity override bases
+        we need to validate the percentage before building the document(dict)"""
+        total_allocation = sum(
+            mvfsv["percentage_allocation"]
+            for mvfsv in data["multivariate_feature_state_values"]
+        )
+        if total_allocation > 100:
+
+            raise InvalidPercentageAllocation(
+                "Total percentage allocation should not be more than 100"
+            )
+        return data
